@@ -16,3 +16,5 @@ from .qusaae import Q_Encoder
 from .qusaae import Q_Decoder
 from .qusaae import Q_Discriminator
 from .quattention import QuAttention
+from .qugat import QuGAT
+from .qugcn import QuGCN
